correction_flag

Function correction_flag 

pub fn correction_flag(slot: &str) -> String
The state key raised for one turn when the user corrects slot: its value changed from one captured value to another. See FlowStack::with_correction.