Struct LiveEventStream
pub struct LiveEventStream { /* private fields */ }Expand description
A [futures::Stream] of LiveEvents from a Live session.
Created by LiveHandle::stream().
Wraps the underlying [broadcast::Receiver] with stream semantics:
- Lagged: if this subscriber falls behind the broadcast buffer, the missed events are skipped and the stream continues with the next available event (no error item is yielded).
- Closed: when the session’s event channel closes, the stream ends
(
next()returnsNone).
Composes with all futures/tokio-stream combinators:
ⓘ
use futures::StreamExt;
let mut stream = handle.stream();
while let Some(ev) = stream.next().await {
match ev {
LiveEvent::TextDelta(t) => print!("{t}"),
LiveEvent::TurnComplete => println!(),
_ => {}
}
}Trait Implementations
impl Debug for LiveEventStream
impl Debug for LiveEventStream
impl Stream for LiveEventStream
impl Stream for LiveEventStream
fn poll_next(
self: Pin<&mut LiveEventStream>,
cx: &mut Context<'_>,
) -> Poll<Option<<LiveEventStream as Stream>::Item>>
fn poll_next( self: Pin<&mut LiveEventStream>, cx: &mut Context<'_>, ) -> Poll<Option<<LiveEventStream as Stream>::Item>>
Attempt to pull out the next value of this stream, registering the
current task for wakeup if the value is not yet available, and returning
None if the stream is exhausted. Read moreAuto Trait Implementations
impl Freeze for LiveEventStream
impl !RefUnwindSafe for LiveEventStream
impl Send for LiveEventStream
impl !Sync for LiveEventStream
impl Unpin for LiveEventStream
impl !UnwindSafe for LiveEventStream