Struct LiveReactor
pub struct LiveReactor { /* private fields */ }Expand description
Ordered collection of reactor rules.
Implementations
impl LiveReactor
impl LiveReactor
pub fn new() -> LiveReactor
pub fn new() -> LiveReactor
Create an empty reactor.
pub fn voice_defaults() -> LiveReactor
pub fn voice_defaults() -> LiveReactor
Create a reactor with the default voice-flow rules.
pub fn add_rule(&mut self, rule: impl ReactorRule + 'static)
pub fn add_rule(&mut self, rule: impl ReactorRule + 'static)
Add a rule to the end of the ordered rule list.
pub fn react(&self, event: &ReactorEvent) -> Vec<Reaction>
pub fn react(&self, event: &ReactorEvent) -> Vec<Reaction>
Run all rules against an event and collect reactions in rule order.
pub fn voice_state(&self) -> VoiceRuntimeState
pub fn voice_state(&self) -> VoiceRuntimeState
Return a snapshot of the current voice runtime state.