pub struct GcloudTokenProvider { /* private fields */ }Expand description
Token provider that shells out to gcloud auth print-access-token,
caching the result with a configurable TTL.
Implementations
Sourceimpl GcloudTokenProvider
impl GcloudTokenProvider
Sourcepub fn new(ttl: Duration) -> GcloudTokenProvider
pub fn new(ttl: Duration) -> GcloudTokenProvider
Create a new provider with the given cache TTL (recommended: 45 minutes).