Struct JoinTextAgent
pub struct JoinTextAgent { /* private fields */ }Expand description
Waits for dispatched background tasks and collects their results.
Implementations
impl JoinTextAgent
impl JoinTextAgent
pub fn new(name: impl Into<String>, registry: TaskRegistry) -> JoinTextAgent
pub fn new(name: impl Into<String>, registry: TaskRegistry) -> JoinTextAgent
Create a new join agent that waits for dispatched tasks.
pub fn targets(self, names: Vec<String>) -> JoinTextAgent
pub fn targets(self, names: Vec<String>) -> JoinTextAgent
Only wait for specific named tasks.
pub fn timeout(self, timeout: Duration) -> JoinTextAgent
pub fn timeout(self, timeout: Duration) -> JoinTextAgent
Set a timeout for waiting.