Struct NeedsFulfillment
pub struct NeedsFulfillment { /* private fields */ }Expand description
Tracks need fulfillment per phase and recommends repair actions.
Implementations
impl NeedsFulfillment
impl NeedsFulfillment
pub fn new(config: RepairConfig) -> NeedsFulfillment
pub fn new(config: RepairConfig) -> NeedsFulfillment
Create with the given configuration.
pub fn evaluate(
&mut self,
phase: &str,
needs: &[String],
state: &State,
) -> RepairAction
pub fn evaluate( &mut self, phase: &str, needs: &[String], state: &State, ) -> RepairAction
Evaluate whether repair action is needed for the current phase.
Call after extractors run. Returns the recommended action.
pub fn reset_all(&mut self)
pub fn reset_all(&mut self)
Reset all tracking.