parse_telephone_event

Function parse_telephone_event 

pub fn parse_telephone_event(payload: &[u8]) -> Option<TelephoneEvent>
Parse an RFC 4733 telephone-event payload (the 4-byte named-event form).

The caller decides whether a packet is a telephone event from the payload type negotiated in SDP — this parses the payload of one that is.