pub struct MasterKey { /* private fields */ }Expand description
A master key and salt, from which the session keys are derived.
Implementations
Sourceimpl MasterKey
impl MasterKey
Sourcepub fn generate() -> Result<Self>
pub fn generate() -> Result<Self>
A fresh random key and salt from the operating system’s generator.
Sourcepub fn from_inline(inline: &str) -> Option<Self>
pub fn from_inline(inline: &str) -> Option<Self>
Parse an SDES inline: key parameter (with or without the prefix).
A lifetime (|2^31) is accepted and ignored; an MKI (|1:4) is not
supported and fails the parse.