check_contracts

Function check_contracts 

pub fn check_contracts(agents: &[AgentBuilder]) -> Vec<ContractViolation>
Check state contracts across a set of agents.

Validates that:

  • Every key a consumer reads is produced by some agent
  • No two agents write the same key (race condition detection)
  • Every key a producer writes is consumed by some agent (dead code detection)