connect

Function connect 

pub async fn connect(
    config: SessionConfig,
) -> Result<SessionHandle, SessionError>
Connect to the Gemini Multimodal Live API with the default transport and return a session handle.

Timeouts, reconnection, a custom transport or codec, or a wire recorder: ConnectBuilder, of which this is the zero-option form.