Enum Pred
pub enum Pred {
Always,
IsTrue(String),
IsSet(String),
Eq(String, Value),
Captured(Vec<String>),
CalledOk(String),
Done(String),
All(Vec<Pred>),
Any(Vec<Pred>),
Not(Box<Pred>),
}Expand description
A serializable predicate atom — the closed set of guard primitives.
Variants
Always
Always true.
IsTrue(String)
State key holds boolean true.
IsSet(String)
State key is present.
Eq(String, Value)
State key equals the given JSON value.
Captured(Vec<String>)
All of the given state keys are present (e.g. extracted slots).
CalledOk(String)
The named tool has completed successfully at least once.
Done(String)
The named step is done.
All(Vec<Pred>)
Conjunction.
Any(Vec<Pred>)
Disjunction.
Not(Box<Pred>)
Negation.