pub fn correction_flag(slot: &str) -> StringExpand description
The state key raised for one turn when the user corrects slot: its
value changed from one captured value to another. See
FlowStack::with_correction.
pub fn correction_flag(slot: &str) -> StringThe state key raised for one turn when the user corrects slot: its
value changed from one captured value to another. See
FlowStack::with_correction.