Struct TemporalRegistry
pub struct TemporalRegistry { /* private fields */ }Expand description
Registry of temporal patterns evaluated on events and/or timer ticks.
Implementations
impl TemporalRegistry
impl TemporalRegistry
pub fn new() -> TemporalRegistry
pub fn new() -> TemporalRegistry
Create an empty registry.
pub fn add(&mut self, pattern: TemporalPattern)
pub fn add(&mut self, pattern: TemporalPattern)
Add a pattern to the registry.
pub fn check_all(
&self,
state: &State,
event: Option<&SessionEvent>,
writer: &Arc<dyn SessionWriter>,
) -> Vec<Pin<Box<dyn Future<Output = ()> + Send>>>
pub fn check_all( &self, state: &State, event: Option<&SessionEvent>, writer: &Arc<dyn SessionWriter>, ) -> Vec<Pin<Box<dyn Future<Output = ()> + Send>>>
Check all patterns and return the futures for those that fired.
Called by the control-lane processor on each event and optionally on a periodic timer tick.
pub fn needs_timer(&self) -> bool
pub fn needs_timer(&self) -> bool
Returns true if any registered pattern’s detector needs periodic
timer checks (i.e. its PatternDetector::needs_timer returns true).