pub struct Loop {
pub body: Box<Composable>,
pub max: u32,
pub until: Option<LoopPredicate>,
pub name: Option<String>,
pub description: Option<String>,
/* private fields */
}Expand description
Loop: repeat an agent or pipeline up to max times, or until a predicate.
Fields
body: Box<Composable>The composable to repeat.
max: u32Maximum number of iterations.
until: Option<LoopPredicate>Optional early-exit predicate evaluated after each iteration.
name: Option<String>Name given to the compiled agent (default "loop").
description: Option<String>Human-readable description, shown in Debug output.
Implementations
Sourceimpl Loop
impl Loop
Sourcepub fn builder(name: &str) -> Self
pub fn builder(name: &str) -> Self
Create a loop builder with a body agent and default max iterations.
let refine = Loop::builder("refine")
.step(AgentBuilder::new("refine"))
.max_iterations(5);
assert_eq!(refine.max, 5);Sourcepub fn middleware(self, middleware: impl Into<MiddlewareComposite>) -> Self
pub fn middleware(self, middleware: impl Into<MiddlewareComposite>) -> Self
Attach middleware to the loop agent (e.g. M::on_loop(|i| …)), observed
on every iteration.
Sourcepub fn step(self, agent: impl Into<Composable>) -> Self
pub fn step(self, agent: impl Into<Composable>) -> Self
Set the body composable to loop over.
Sourcepub fn max_iterations(self, n: u32) -> Self
pub fn max_iterations(self, n: u32) -> Self
Set a maximum number of iterations.