pub fn map_over(agent: AgentBuilder, concurrency: usize) -> MapOverExpand description
Map-over: apply a single agent to multiple items concurrently.
Returns a MapOver composable that stores the agent template and concurrency limit.
pub fn map_over(agent: AgentBuilder, concurrency: usize) -> MapOverMap-over: apply a single agent to multiple items concurrently.
Returns a MapOver composable that stores the agent template and concurrency limit.