Struct GoogleAITokenAuth
pub struct GoogleAITokenAuth { /* private fields */ }Expand description
Google AI OAuth2 access token authentication.
The access token is included directly in the WebSocket URL.
Implementations
impl GoogleAITokenAuth
impl GoogleAITokenAuth
pub fn new(access_token: impl Into<String>) -> GoogleAITokenAuth
pub fn new(access_token: impl Into<String>) -> GoogleAITokenAuth
Create a new Google AI token auth provider with the given access token.