pub fn secure_audio_answer(
session_id: u64,
host: &str,
port: u16,
payload_type: u8,
telephone_event_pt: Option<u8>,
crypto: &str,
) -> StringExpand description
audio_answer for an RTP/SAVP offer: the answer uses the secure
profile and carries crypto, the value of our a=crypto: line (the tag
and suite of the offer line we accept, and our own key).